@@ -57,9 +57,9 @@ module Rouge
 
       def self.gen_command_state(name='')
         state(:"command#{name}") do
-          mixin :word
+          rule %r/#/, Comment, :comment
 
-          rule %r/##{NOT_CHARS[END_LINE]}+/, Comment::Single
+          mixin :word
 
           rule %r/(?=#{CHARS[END_WORD]})/ do
             push :"params#{name}"
@@ -163,6 +163,11 @@ module Rouge
         rule %r/\\./m, Str::Escape
       end
 
+      state :comment do
+        rule %r/.*[^\\]\n/, Comment, :pop!
+        rule %r/.*\\\n/, Comment
+      end
+
       state :string do
         rule %r/"/, Str::Double, :pop!
         mixin :interp
