@@ -10,5 +10,9 @@ describe Rouge::Lexers::Liquid do
     it 'guesses by filename' do
       assert_guess :filename => 'file.liquid'
     end
+
+    it 'guesses by mimetype' do
+      assert_guess mimetype: 'text/html+liquid'
+    end
   end
 end
